package com.ruoyi.project.pssr.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.pssr.mapper.TPssrRegionMapper;
import com.ruoyi.project.pssr.domain.TPssrRegion;
import com.ruoyi.project.pssr.service.ITPssrRegionService;

/**
 * pssr区域管理Service业务层处理
 *
 * @author ssy
 * @date 2024-09-18
 */
@Service
public class TPssrRegionServiceImpl implements ITPssrRegionService
{
    @Autowired
    private TPssrRegionMapper tPssrRegionMapper;

    /**
     * 查询pssr区域管理
     *
     * @param id pssr区域管理ID
     * @return pssr区域管理
     */
    @Override
    public TPssrRegion selectTPssrRegionById(Long id)
    {
        return tPssrRegionMapper.selectTPssrRegionById(id);
    }

    /**
     * 查询pssr区域管理列表
     *
     * @param tPssrRegion pssr区域管理
     * @return pssr区域管理
     */
    @Override
    public List<TPssrRegion> selectTPssrRegionList(TPssrRegion tPssrRegion)
    {
        return tPssrRegionMapper.selectTPssrRegionList(tPssrRegion);
    }

    /**
     * 新增pssr区域管理
     *
     * @param tPssrRegion pssr区域管理
     * @return 结果
     */
    @Override
    public int insertTPssrRegion(TPssrRegion tPssrRegion)
    {
        return tPssrRegionMapper.insertTPssrRegion(tPssrRegion);
    }

    /**
     * 修改pssr区域管理
     *
     * @param tPssrRegion pssr区域管理
     * @return 结果
     */
    @Override
    public int updateTPssrRegion(TPssrRegion tPssrRegion)
    {
        return tPssrRegionMapper.updateTPssrRegion(tPssrRegion);
    }

    /**
     * 批量删除pssr区域管理
     *
     * @param ids 需要删除的pssr区域管理ID
     * @return 结果
     */
    @Override
    public int deleteTPssrRegionByIds(Long[] ids)
    {
        return tPssrRegionMapper.deleteTPssrRegionByIds(ids);
    }

    /**
     * 删除pssr区域管理信息
     *
     * @param id pssr区域管理ID
     * @return 结果
     */
    @Override
    public int deleteTPssrRegionById(Long id)
    {
        return tPssrRegionMapper.deleteTPssrRegionById(id);
    }
}
